@@ -1,6 +1,6 @@
 use v6;
 
-unit module TAP:ver<0.3.0>;
+unit module TAP:ver<0.3.1>;
 
 role Entry {
     has Str:D $.raw is required handles <Str>;
@@ -376,9 +376,9 @@ class Output::Handle does Output {
 }
 
 class Output::Supplier does Output {
-    has Supplier:D $.supply is required;
+    has Supplier:D $.supplier is required;
     method print(Str $value) {
-        $!supply.emit($value);
+        $!supplier.emit($value);
     }
 }
 
